@@ -135,7 +135,7 @@ Supporting OS subroutines required: <<close>>, <<fstat>>, <<isatty>>,
 
 #if defined(LIBC_SCCS) && !defined(lint)
 /*static char *sccsid = "from: @(#)vfprintf.c	5.50 (Berkeley) 12/16/92";*/
-static char *rcsid = "$Id: vfprintf.c,v 1.9 2004/05/26 00:19:14 jjohnstn Exp $";
+static char *rcsid = "$Id: vfprintf.c,v 1.11 2005/02/08 01:33:16 jjohnstn Exp $";
 #endif /* LIBC_SCCS and not lint */
 
 /*
@@ -239,7 +239,6 @@ __sbprintf(fp, fmt, ap)
 	unsigned char buf[BUFSIZ];
 
 	/* copy the important variables */
-	fake._data = fp->_data;
 	fake._flags = fp->_flags & ~__SNBF;
 	fake._file = fp->_file;
 	fake._cookie = fp->_cookie;
@@ -322,8 +321,8 @@ _DEFUN (VFPRINTF, (fp, fmt0, ap),
 	_CONST char *fmt0 _AND
 	va_list ap)
 {
-  CHECK_INIT (fp);
-  return _VFPRINTF_R (fp->_data, fp, fmt0, ap);
+  CHECK_INIT (_REENT);
+  return _VFPRINTF_R (_REENT, fp, fmt0, ap);
 }
 
 int 
