@@ -49,11 +49,11 @@ extern int   _EXFUN(__srefill,(FILE *fp));
 
 /* Called by the main entry point fns to ensure stdio has been initialized.  */
 
-#define CHECK_INIT(fp) \
+#define CHECK_INIT(ptr) \
   do						\
     {						\
-      if (_REENT && !_REENT->__sdidinit)	\
-	__sinit (_REENT);			\
+      if ((ptr) && !(ptr)->__sdidinit)		\
+	__sinit (ptr);				\
     }						\
   while (0)
 
@@ -95,7 +95,11 @@ char *_EXFUN(_llicvt,(char *, long long, char));
 #ifdef __SINGLE_THREAD__
 #define __sfp_lock_acquire()
 #define __sfp_lock_release()
+#define __sinit_lock_acquire()
+#define __sinit_lock_release()
 #else
 _VOID _EXFUN(__sfp_lock_acquire,(_VOID));
 _VOID _EXFUN(__sfp_lock_release,(_VOID));
+_VOID _EXFUN(__sinit_lock_acquire,(_VOID));
+_VOID _EXFUN(__sinit_lock_release,(_VOID));
 #endif
