@@ -9,17 +9,17 @@
 int
 __fpclassifyf (float x)
 {
-  unsigned int w;
+  __uint32_t w;
 
   GET_FLOAT_WORD(w,x);
   
   if (w == 0x00000000 || w == 0x80000000)
     return FP_ZERO;
   else if ((w >= 0x00800000 && w <= 0x7f7fffff) ||
-           (w >= 0xff7fffff && w <= 0x80800000))
+           (w >= 0x80800000 && w <= 0xff7fffff))
     return FP_NORMAL;
   else if ((w >= 0x00000001 && w <= 0x007fffff) ||
-           (w >= 0x807fffff && w <= 0x80000001))
+           (w >= 0x80000001 && w <= 0x807fffff))
     return FP_SUBNORMAL;
   else if (w == 0x7f800000 || w == 0xff800000)
     return FP_INFINITE;
@@ -30,7 +30,7 @@ __fpclassifyf (float x)
 int
 __fpclassifyd (double x)
 {
-  unsigned int msw, lsw;
+  __uint32_t msw, lsw;
 
   EXTRACT_WORDS(msw,lsw,x);
 
@@ -38,10 +38,10 @@ __fpclassifyd (double x)
       (msw == 0x80000000 && lsw == 0x00000000))
     return FP_ZERO;
   else if ((msw >= 0x00100000 && msw <= 0x7fefffff) ||
-           (msw >= 0xffefffff && msw <= 0x80100000))
+           (msw >= 0x80100000 && msw <= 0xffefffff))
     return FP_NORMAL;
   else if ((msw >= 0x00000000 && msw <= 0x000fffff) ||
-           (msw >= 0x800fffff && msw <= 0x80000000))
+           (msw >= 0x80000000 && msw <= 0x800fffff))
     /* zero is already handled above */
     return FP_SUBNORMAL;
   else if ((msw == 0x7ff00000 && lsw == 0x00000000) ||
